==> prestashop_1.4.0.7.zip: prestashop/modules/twenga/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{twenga}prestashop>TwengaObj_2823b98d043387f608f16d5830d63f5f'] = 'Para activar el módulo Twenga, la constante \"PARTNER_AUTH_KEY\" debe estar definida. La instalación por defecto de PrestaShop contiene este valor.';
$_MODULE['<{twenga}prestashop>TwengaObj_9f7cd403f4ab77ce8c00426d4a01345e'] = 'El objeto para validar los campos debe ser una instancia de la clase TwengaFields';
$_MODULE['<{twenga}prestashop>TwengaObj_b78d4ca3fa82bab9e21c8110511ed947'] = 'La devolución XML de la respuesta HTTP no puede ser analizada:';
$_MODULE['<{twenga}prestashop>TwengaObj_7edc522b57a063ef075b68fdb791af40'] = 'la respuesta HTTP está vacía';
$_MODULE['<{twenga}prestashop>TwengaObj_d00d3f61833c8686be3f0ca7df670e20'] = 'La llamada a los servicios Web Twenga no se ha obtenido con éxito y a devuelto un estado HTTP de %d. Lo que significa:';
$_MODULE['<{twenga}prestashop>TwengaObj_5177c3a8e526ccb227441827d43d9583'] = 'La función que ha llamado no existe';
$_MODULE['<{twenga}prestashop>TwengaObj_3718cdfdc7439f35aed9f053b5991baf'] = 'Un campo requerido está vacío.';
$_MODULE['<{twenga}prestashop>TwengaObj_f97fd38d65fe891d07fc1a157b0752a2'] = 'El tipo de parámetro que ha enviado es diferente del que se esperaba.';
$_MODULE['<{twenga}prestashop>TwengaObj_737b702af5cbf3c4b0e7404592bae85e'] = 'El hash key no es válido';
$_MODULE['<{twenga}prestashop>TwengaObj_c54550e963195bd4e80b862f40b8d574'] = 'Se requiere el hash key';
$_MODULE['<{twenga}prestashop>TwengaObj_c4e170c475b0285f284ccb066bcd81f4'] = 'No se han encontrado pedidos. Compruebe los parámetros que transmite';
$_MODULE['<{twenga}prestashop>TwengaObj_54441256ce04ab07a29463646d0a9931'] = 'Se requiere una autentificación.';
$_MODULE['<{twenga}prestashop>TwengaObj_802b207b05fe5cea22e11b9db804b33d'] = 'La autentificación ha fracasado.';
$_MODULE['<{twenga}prestashop>TwengaObj_629a8cfa226f98886062bfdc9666e266'] = 'La URL no es válida.';
$_MODULE['<{twenga}prestashop>TwengaObj_9fb66ea632c1aff220b180918df3c77c'] = 'El servidor ha encontrado un \"internal server error\".';
$_MODULE['<{twenga}prestashop>TwengaObj_6e182f2ba494a6720ce552ed2a255403'] = 'El servidor no está accesible por el momento';
$_MODULE['<{twenga}prestashop>TwengaObj_4252fb7eb531ed1ec250e5c16f8ced37'] = 'La llamada a los servicios Web Twenga a devuelto un estado HTTP inesperado:';
$_MODULE['<{twenga}prestashop>TwengaObj_5619f08f21127bd8f72ec9bbb25031ac'] = 'Error  n°';
$_MODULE['<{twenga}prestashop>twenga_400b0c914f01bcecf50b936e652695b2'] = 'El API de Twenga';
$_MODULE['<{twenga}prestashop>twenga_aa2bebad4fe3e659723e56cc7fcc6b1c'] = 'Exporte sus productos en Twenga.com y utilice el Tracker de Twenga para los pedidos de sus consumidores.';
$_MODULE['<{twenga}prestashop>twenga_69e591b18e717d483dbaa8e3ce89ce59'] = 'Los parámetros no son autorizados (ver detalles):';
$_MODULE['<{twenga}prestashop>twenga_75a462904fadc0cc16d084efaef4a9d0'] = 'Se ha producido un error con un método de API Twenga (ver detalles):';
$_MODULE['<{twenga}prestashop>twenga_cecc441ee7cb4cbbf1953d44018706de'] = 'Su “Haskell” no es válido: Compruebe el email enviado por Twenga.';
$_MODULE['<{twenga}prestashop>twenga_0483e8a340c21e92e606aa0cd2bafbe7'] = 'Su nombre de usuario no es válido. Compruebe el email enviado por Twenga.';
$_MODULE['<{twenga}prestashop>twenga_54d92b2c87281ba0247f14a8eaea3278'] = 'Su contraseña no es válida. Compruebe el email enviado por Twenga.';
$_MODULE['<{twenga}prestashop>twenga_b0d43a97cdf2e31e3d6b26640c2e71ee'] = 'Su autentificación ha fracasado.';
$_MODULE['<{twenga}prestashop>twenga_638a1f975b1d8361fcd459c532db6634'] = 'Compruebe el email enviado por Twenga en el momento de la inscripción. Si los errores continúan contacte con el servicio de Twenga.';
$_MODULE['<{twenga}prestashop>twenga_ddedf0f7b923553ef46616375e521381'] = 'Se ha producido un error al pasar los parámetros a el API Twenga.';
$_MODULE['<{twenga}prestashop>twenga_378f76d06c0d43d9fe5b5ab561e06d09'] = 'Para utilizar el webservicio de Twenga, debe activar la extensión “curl” de PHP';
$_MODULE['<{twenga}prestashop>twenga_0c619ac2ab02e76d399db8e053344f9d'] = 'Twenga';
$_MODULE['<{twenga}prestashop>twenga_0e78527dac17a461f84dceee220109cf'] = 'Después de inscribirse al API de Twenga, Twenga le envía su “Haskell”.';
$_MODULE['<{twenga}prestashop>twenga_a66daa775d445ee7da1bb20667b7c8e6'] = 'Flujo RSS';
$_MODULE['<{twenga}prestashop>twenga_21baf392bfae2dadba6813e9fb843141'] = 'Hashkey';
$_MODULE['<{twenga}prestashop>twenga_99dea78007133396a7b8ed70578ac6ae'] = 'Login';
$_MODULE['<{twenga}prestashop>twenga_dc647eb65e6711e155375218212b3964'] = 'Contraseña';
$_MODULE['<{twenga}prestashop>twenga_43781db5c40ecc39fd718685594f0956'] = 'Guardar';
$_MODULE['<{twenga}prestashop>twenga_787ad0b7a17de4ad6b1711bbf8d79fcb'] = 'Inscripción';
$_MODULE['<{twenga}prestashop>twenga_113560aefce6245acec25d96748d1bf7'] = 'Para preparar su inscripción al API de Twenga,';
$_MODULE['<{twenga}prestashop>twenga_1d93204c72f98ee5d358d6d562f1942b'] = 'compruebe el siguiente formulario y pulse en “guardar” para acceder al formulario de inscripción de Twenga';
$_MODULE['<{twenga}prestashop>twenga_87fa3060dcb794dee724d4cb59b13cd6'] = 'La URL del sitio';
$_MODULE['<{twenga}prestashop>twenga_1ce44171ccfff23c4fc2c836ad6543f4'] = 'Flujo RSS, lista de productos en xml.';
$_MODULE['<{twenga}prestashop>twenga_670e0c29cdde1886890aebc751cd6e89'] = 'Valor rellenado automáticamente, no cambiar.';
$_MODULE['<{twenga}prestashop>twenga_59716c97497eb9694541f7c3d37b1a4d'] = 'País';
$_MODULE['<{twenga}prestashop>twenga_95f01a5bae7b4b64a76372538e4fd315'] = 'El país de la empresa E-Comercio. Utilice el código ISO_3166-1 Alpha-2 para el formato del país';
$_MODULE['<{twenga}prestashop>twenga_734b599bad38d4210614bc176c53fefe'] = 'Nombre del sitio';
$_MODULE['<{twenga}prestashop>twenga_dff4bf10409100d989495c6d5486035e'] = 'Apellido';
$_MODULE['<{twenga}prestashop>twenga_04176f095283bc729f1e3926967e7034'] = 'Nombre';
$_MODULE['<{twenga}prestashop>twenga_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'Email';
$_MODULE['<{twenga}prestashop>twenga_bcc254b55c4a1babdf1dcb82c207506b'] = 'Teléfono';
$_MODULE['<{twenga}prestashop>twenga_28bea34e08fa23a7d394c93bad717733'] = 'Nombre del organismo';
$_MODULE['<{twenga}prestashop>twenga_4ff5049a0938728934387c4d9cf38f94'] = 'Información jurídica';
$_MODULE['<{twenga}prestashop>twenga_dfd7564600980a3470f2ec24766653fe'] = 'Información jurídica de la empresa.';
$_MODULE['<{twenga}prestashop>twenga_dd7bf230fde8d4836917806aff6a6b27'] = 'Dirección';
$_MODULE['<{twenga}prestashop>twenga_572ed696f21038e6cc6c86bb272a3222'] = 'Código postal';
$_MODULE['<{twenga}prestashop>twenga_57d056ed0984166336b7879c2af3657f'] = 'Ciudad';
$_MODULE['<{twenga}prestashop>twenga_c9cc8cce247e49bae79f15173ce97354'] = 'Guardar';
$_MODULE['<{twenga}prestashop>twenga_435ad0ad5987e5c3b1304cf00472216d'] = 'Si no es redirigido hacia el formulario de inscripción de la API de Twenga, pulse en los siguientes links:';
$_MODULE['<{twenga}prestashop>twenga_58b6e05ecb12409685dec606271ca1ad'] = 'Links en el formulario de inscripción de Twenga';
$_MODULE['<{twenga}prestashop>twenga_fcb0c2a30548efc7048ea4bdfa4eba05'] = 'Anular el tracking';
$_MODULE['<{twenga}prestashop>twenga_08473b95892d1cb8265ff2716cb81d54'] = 'Para anular el tracking, pulse en el siguiente link:';
$_MODULE['<{twenga}prestashop>twenga_bcfaccebf745acfd5e75351095a5394a'] = 'Anular';
$_MODULE['<{twenga}prestashop>twenga_2938a03ab100963b7349d83257fa9333'] = 'Activar el tracking';
$_MODULE['<{twenga}prestashop>twenga_cd07439a0c70b97a595de73218094a36'] = 'Para activar el tracking, pulse en el siguiente link:';
$_MODULE['<{twenga}prestashop>twenga_a13367a8e2a3f3bf4f3409079e3fdf87'] = 'Activar';

==> prestashop_1.4.0.9.zip: prestashop/modules/twenga/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{twenga}prestashop>twenga_400b0c914f01bcecf50b936e652695b2'] = 'El API de Twenga';
$_MODULE['<{twenga}prestashop>twenga_aa2bebad4fe3e659723e56cc7fcc6b1c'] = 'Exporte sus productos en Twenga.com y utilice el Tracker de Twenga para los pedidos de sus consumidores.';
$_MODULE['<{twenga}prestashop>twenga_69e591b18e717d483dbaa8e3ce89ce59'] = 'Los parámetros no son autorizados (ver detalles):';
$_MODULE['<{twenga}prestashop>twenga_75a462904fadc0cc16d084efaef4a9d0'] = 'Se ha producido un error con un método de API Twenga (ver detalles):';
$_MODULE['<{twenga}prestashop>twenga_cecc441ee7cb4cbbf1953d44018706de'] = 'Su “Haskell” no es válido: Compruebe el email enviado por Twenga.';
$_MODULE['<{twenga}prestashop>twenga_0483e8a340c21e92e606aa0cd2bafbe7'] = 'Su nombre de usuario no es válido. Compruebe el email enviado por Twenga.';
$_MODULE['<{twenga}prestashop>twenga_54d92b2c87281ba0247f14a8eaea3278'] = 'Su contraseña no es válida. Compruebe el email enviado por Twenga.';
$_MODULE['<{twenga}prestashop>twenga_b0d43a97cdf2e31e3d6b26640c2e71ee'] = 'Su autentificación ha fracasado.';
$_MODULE['<{twenga}prestashop>twenga_638a1f975b1d8361fcd459c532db6634'] = 'Compruebe el email enviado por Twenga en el momento de la inscripción. Si los errores continúan contacte con el servicio de Twenga.';
$_MODULE['<{twenga}prestashop>twenga_ddedf0f7b923553ef46616375e521381'] = 'Se ha producido un error al pasar los parámetros a el API Twenga.';
$_MODULE['<{twenga}prestashop>twenga_378f76d06c0d43d9fe5b5ab561e06d09'] = 'Para utilizar el webservicio de Twenga, debe activar la extensión “curl” de PHP';
$_MODULE['<{twenga}prestashop>twenga_b0f7b5191764e268fe2d2a781314a0fd'] = 'Durante la recuperación del link de suscripción por el API de Twenga ha aparecido algún error:';
$_MODULE['<{twenga}prestashop>twenga_e7d6c412cbd6e430822d3b0dbad40498'] = 'Referencie sus productos en Twenga: ¡PrestaShop regala 500 clics!';
$_MODULE['<{twenga}prestashop>twenga_f57bb21deb3c9ca234f74bb6435f271f'] = 'Como probar Twenga y disfrutar de los primeros 500 clics gratis:';
$_MODULE['<{twenga}prestashop>twenga_94bce708bfc56c62c6710db3c34db33d'] = 'Etapa 1: pulsar sobre este link especial para inscribirse a \"Twenga Ready to Sell\"';
$_MODULE['<{twenga}prestashop>twenga_4f893ee24950069dd823e083338a456d'] = 'inscribirse';
$_MODULE['<{twenga}prestashop>twenga_d4841389a7d896c92ecb8d81c0f42abf'] = '(se han producido errores: contacte con Twenga)';
$_MODULE['<{twenga}prestashop>twenga_2e7476b2a0122a4b8f8041e08b5e34bc'] = 'Etapa 2: Complete el formulario de inscripción Twenga';
$_MODULE['<{twenga}prestashop>twenga_3526e9eda1bd86bf79472b6abf88ad98'] = 'Etapa 3: Una vez haya recibido su clave Twenga, vuelva aquí y copie esta clave en el campo \"hash key\" así como su login Twenga Ready to Sell.';
$_MODULE['<{twenga}prestashop>twenga_bc88fe7063d7e7da0bf08003f21a1ad2'] = 'Aumente su tráfico - 500 clics gratis';
$_MODULE['<{twenga}prestashop>twenga_d7c78c7a4356df39e7113405bd003ab5'] = 'Su catálogo se referenciará en quince días. Una vez haya utilizado los 500 clics, se facturará al clic por categoría de 0,05€ a 0,15€. Tendrá acceso a una interfaz de gestión completa. Puede irse en cualquier momento previo aviso de un mes.';
$_MODULE['<{twenga}prestashop>twenga_f57624e0e72283c798dbd6cf90eed6ce'] = 'Autentificación';
$_MODULE['<{twenga}prestashop>twenga_c7f7d1a930f6d4118e2a3938bc56d8dc'] = 'Después de haber rellenado las etapas 1 y 2, introduzca la clave Twenga y su login twenga Ready to Sell';
$_MODULE['<{twenga}prestashop>twenga_a66daa775d445ee7da1bb20667b7c8e6'] = 'Flujo RSS';
$_MODULE['<{twenga}prestashop>twenga_21baf392bfae2dadba6813e9fb843141'] = 'Hashkey';
$_MODULE['<{twenga}prestashop>twenga_99dea78007133396a7b8ed70578ac6ae'] = 'Login';
$_MODULE['<{twenga}prestashop>twenga_dc647eb65e6711e155375218212b3964'] = 'Contraseña';
$_MODULE['<{twenga}prestashop>twenga_9915db4a30d338bd75b2880dcdc1a560'] = 'Su catálogo se referenciará en quince días en twenga';
$_MODULE['<{twenga}prestashop>twenga_43781db5c40ecc39fd718685594f0956'] = 'Guardar';
$_MODULE['<{twenga}prestashop>twenga_f7fba53a11823899183e6634a599f66e'] = 'Datos rellenos automáticamente en el formulario de inscripción twenga';
$_MODULE['<{twenga}prestashop>twenga_ce3991031fe3a5153f6d4cae2cbf6a94'] = 'Los siguientes datos aparecen rellenos automáticamente en el momento de la inscripción';
$_MODULE['<{twenga}prestashop>twenga_87fa3060dcb794dee724d4cb59b13cd6'] = 'La URL del sitio';
$_MODULE['<{twenga}prestashop>twenga_1ce44171ccfff23c4fc2c836ad6543f4'] = 'Flujo RSS, lista de productos en xml.';
$_MODULE['<{twenga}prestashop>twenga_670e0c29cdde1886890aebc751cd6e89'] = 'Valor rellenado automáticamente, no cambiar.';
$_MODULE['<{twenga}prestashop>twenga_59716c97497eb9694541f7c3d37b1a4d'] = 'País';
$_MODULE['<{twenga}prestashop>twenga_95f01a5bae7b4b64a76372538e4fd315'] = 'El país de la empresa E-Comercio. Utilice el código ISO_3166-1 Alpha-2 para el formato del país';
$_MODULE['<{twenga}prestashop>twenga_734b599bad38d4210614bc176c53fefe'] = 'Nombre del sitio';
$_MODULE['<{twenga}prestashop>twenga_dff4bf10409100d989495c6d5486035e'] = 'Apellido';
$_MODULE['<{twenga}prestashop>twenga_04176f095283bc729f1e3926967e7034'] = 'Nombre';
$_MODULE['<{twenga}prestashop>twenga_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'Email';
$_MODULE['<{twenga}prestashop>twenga_bcc254b55c4a1babdf1dcb82c207506b'] = 'Teléfono';
$_MODULE['<{twenga}prestashop>twenga_28bea34e08fa23a7d394c93bad717733'] = 'Nombre del organismo';
$_MODULE['<{twenga}prestashop>twenga_4ff5049a0938728934387c4d9cf38f94'] = 'Información jurídica';
$_MODULE['<{twenga}prestashop>twenga_dfd7564600980a3470f2ec24766653fe'] = 'Información jurídica de la empresa.';
$_MODULE['<{twenga}prestashop>twenga_dd7bf230fde8d4836917806aff6a6b27'] = 'Dirección';
$_MODULE['<{twenga}prestashop>twenga_572ed696f21038e6cc6c86bb272a3222'] = 'Código postal';
$_MODULE['<{twenga}prestashop>twenga_57d056ed0984166336b7879c2af3657f'] = 'Ciudad';
$_MODULE['<{twenga}prestashop>twenga_c9cc8cce247e49bae79f15173ce97354'] = 'Guardar';
$_MODULE['<{twenga}prestashop>twenga_fcb0c2a30548efc7048ea4bdfa4eba05'] = 'Anular el tracking';
$_MODULE['<{twenga}prestashop>twenga_08473b95892d1cb8265ff2716cb81d54'] = 'Para anular el tracking, pulse en el siguiente link:';
$_MODULE['<{twenga}prestashop>twenga_bcfaccebf745acfd5e75351095a5394a'] = 'Anular';
$_MODULE['<{twenga}prestashop>twenga_2938a03ab100963b7349d83257fa9333'] = 'Activar el tracking';
$_MODULE['<{twenga}prestashop>twenga_cd07439a0c70b97a595de73218094a36'] = 'Para activar el tracking, pulse en el siguiente link:';
$_MODULE['<{twenga}prestashop>twenga_a13367a8e2a3f3bf4f3409079e3fdf87'] = 'Activar';
$_MODULE['<{twenga}prestashop>TwengaObj_2823b98d043387f608f16d5830d63f5f'] = 'Para activar el módulo Twenga, la constante \"PARTNER_AUTH_KEY\" debe estar definida. La instalación por defecto de PrestaShop contiene este valor.';
$_MODULE['<{twenga}prestashop>TwengaObj_9f7cd403f4ab77ce8c00426d4a01345e'] = 'El objeto para validar los campos debe ser una instancia de la clase TwengaFields';
$_MODULE['<{twenga}prestashop>TwengaObj_b78d4ca3fa82bab9e21c8110511ed947'] = 'La devolución XML de la respuesta HTTP no puede ser analizada:';
$_MODULE['<{twenga}prestashop>TwengaObj_7edc522b57a063ef075b68fdb791af40'] = 'la respuesta HTTP está vacía';
$_MODULE['<{twenga}prestashop>TwengaObj_d00d3f61833c8686be3f0ca7df670e20'] = 'La llamada a los servicios Web Twenga no se ha obtenido con éxito y a devuelto un estado HTTP de %d. Lo que significa:';
$_MODULE['<{twenga}prestashop>TwengaObj_5177c3a8e526ccb227441827d43d9583'] = 'La función que ha llamado no existe';
$_MODULE['<{twenga}prestashop>TwengaObj_3718cdfdc7439f35aed9f053b5991baf'] = 'Un campo requerido está vacío.';
$_MODULE['<{twenga}prestashop>TwengaObj_f97fd38d65fe891d07fc1a157b0752a2'] = 'El tipo de parámetro que ha enviado es diferente del que se esperaba.';
$_MODULE['<{twenga}prestashop>TwengaObj_737b702af5cbf3c4b0e7404592bae85e'] = 'El hash key no es válido';
$_MODULE['<{twenga}prestashop>TwengaObj_c54550e963195bd4e80b862f40b8d574'] = 'Se requiere el hash key';
$_MODULE['<{twenga}prestashop>TwengaObj_c4e170c475b0285f284ccb066bcd81f4'] = 'No se han encontrado pedidos. Compruebe los parámetros que transmite';
$_MODULE['<{twenga}prestashop>TwengaObj_54441256ce04ab07a29463646d0a9931'] = 'Se requiere una autentificación.';
$_MODULE['<{twenga}prestashop>TwengaObj_802b207b05fe5cea22e11b9db804b33d'] = 'La autentificación ha fracasado.';
$_MODULE['<{twenga}prestashop>TwengaObj_629a8cfa226f98886062bfdc9666e266'] = 'La URL no es válida.';
$_MODULE['<{twenga}prestashop>TwengaObj_9fb66ea632c1aff220b180918df3c77c'] = 'El servidor ha encontrado un \"internal server error\".';
$_MODULE['<{twenga}prestashop>TwengaObj_6e182f2ba494a6720ce552ed2a255403'] = 'El servidor no está accesible por el momento';
$_MODULE['<{twenga}prestashop>TwengaObj_4252fb7eb531ed1ec250e5c16f8ced37'] = 'La llamada a los servicios Web Twenga a devuelto un estado HTTP inesperado:';
$_MODULE['<{twenga}prestashop>TwengaObj_5619f08f21127bd8f72ec9bbb25031ac'] = 'Error  n°';
